@@ -1,6 +1,6 @@
 package Weixin::Client;
 use strict;
-use FindBin qw($Bin);
+use File::Spec;
 use Weixin::Util;
 use LWP::UserAgent;
 use Weixin::UserAgent;
@@ -18,13 +18,14 @@ use base qw(
     Weixin::Client::Base
 );
 
-our $VERSION = "1.4";
+our $VERSION = "1.5";
 
 sub new{
     my $class = shift;
     my %p = @_;
     my $agent = 'Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/37.0.2062'; 
-    my $cookie_filename = $p{login_file} || "$Bin/weixin_client_login.dat";
+    my $tmpdir = File::Spec->tmpdir();
+    my $cookie_filename = $p{login_file} || "$tmpdir/weixin_client_login.dat";
     my $self = {
         cookie_jar              => HTTP::Cookies->new(hide_cookie2=>1,file=>$cookie_filename,autosave=>1),
         debug                   => $p{debug},
@@ -53,6 +54,7 @@ sub new{
         plugin_num              => 0,
         plugins                 => {},
         ua_retry_times          => 5,
+        tmpdir                  => $tmpdir,
         client_version          => $VERSION,
     };
     $self->{ua} = LWP::UserAgent->new(
